@@ -2,10 +2,10 @@ yadirGetKeyWordsBids <- function(KeywordIds    = NULL,
                                  AdGroupIds    = NULL,
                                  CampaignIds   = NULL,
                                  AuctionBids   = c(NA, "search", "network"),
-                                 Login         = NULL,
+                                 Login         = getOption("ryandexdirect.user"),
                                  Token         = NULL,
-                                 AgencyAccount = NULL,
-                                 TokenPath     = getwd()) {
+                                 AgencyAccount = getOption("ryandexdirect.agency_account"),
+                                 TokenPath     = yadirTokenPath()) {
   # start time
   start_time  <- Sys.time()
   
@@ -206,7 +206,7 @@ yadirGetKeyWordsBids <- function(KeywordIds    = NULL,
   }
 }
   
-  out <- dplyr::bind_rows(res_flatting) 
+  out <- map_df(res_flatting, flatten)
   end_time <- Sys.time()
   
   message("Duration: ", round(difftime(end_time, start_time, units = "secs"), 0), " secs")
