@@ -1,5 +1,5 @@
 yadirGetToken <-
-function(Login = NULL, TokenPath = getwd()){
+function(Login = NULL, TokenPath = yadirTokenPath()){
   # open browser
   browseURL("https://oauth.yandex.ru/authorize?response_type=token&client_id=365a2d0a675c462d90ac145d4f5948cc")
   
